%define major     5
%define libname   %mklibname onig %{major}
%define develname %mklibname oniguruma -d

# comment out when not a revised release
#define revised rev1
#define sub_ver r1

%define up_ver  6.9.6

Name:           oniguruma
Version:        %{up_ver}%{?sub_ver}
Release:        %mkrel 1
Summary:        Regex Library Supporting Different Character Encodings
License:        BSD
Group:          System/Libraries
Url:            https://github.com/kkos/oniguruma
Source:         https://github.com/kkos/oniguruma/releases/download/v%{up_ver}%{?revised:_%revised}/onig-%{up_ver}%{?revised:-%revised}.tar.gz
BuildRequires:  pkgconfig

%description
Oniguruma is a regular expressions library. The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

#------------------------------------------------

%package -n     %{libname}
Summary:        Regex Library Supporting Different Character Encodings
Group:          System/Libraries
# kill the onig pkg
Obsoletes:      %{_lib}onig2 < 5.9.6-3

%description -n %{libname}
Oniguruma is a regular expressions library. The characteristics of
this library is that different character encoding for every regular
expression object can be specified.

Supported character encodings: ASCII, UTF-8, UTF-16BE, UTF-16LE,
UTF-32BE, UTF-32LE, EUC-JP, EUC-TW, EUC-KR, EUC-CN, Shift_JIS, Big5, GB
18030, KOI8-R, KOI8, ISO-8859-1, ISO-8859-2, ISO-8859-3, ISO-8859-4,
ISO-8859-5, ISO-8859-6, ISO-8859-7, ISO-8859-8, ISO-8859-9,
ISO-8859-10, ISO-8859-11, ISO-8859-13, ISO-8859-14, ISO-8859-15,
ISO-8859-16.

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       onig-devel = %{version}-%{release}
# kill the onig pkg
Obsoletes:      %{_lib}onig-devel < 5.9.6-3

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------
%prep
%setup -q -n onig-%{up_ver}

cp -rp sample/ examples

%build
%configure \
           --enable-posix-api \
           --disable-static   \
           --disable-silent-rules
%make_build

%install
%make_install

# we don't want these
find %{buildroot} -name "*.la" -delete

%files -n %{libname}
%{_libdir}/libonig.so.%{major}{,.*}

%files -n %{develname}
%doc AUTHORS COPYING HISTORY index.html index_ja.html README
%doc doc/* examples/
%{_bindir}/onig-config
%{_includedir}/oniguruma.h
%{_includedir}/oniggnu.h
%{_includedir}/onigposix.h
%{_libdir}/libonig.so
%{_libdir}/pkgconfig/oniguruma.pc


%changelog
* Sun Nov 08 2020 daviddavid <daviddavid> 6.9.6-1.mga8
+ Revision: 1643554
- new version: 6.9.6, fixes CVE-2020-26159 (mga#27387)

* Tue May 12 2020 daviddavid <daviddavid> 6.9.5r1-1.mga8
+ Revision: 1583247
- new version: 6.9.5-rev1

* Tue Feb 18 2020 umeabot <umeabot> 6.9.4-2.mga8
+ Revision: 1539044
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Nov 29 2019 daviddavid <daviddavid> 6.9.4-1.mga8
+ Revision: 1463681
- new version: 6.9.4
- fixes CVE-2019-19246 CVE-2019-19204 CVE-2019-19203 CVE-2019-19012

* Fri Aug 23 2019 daviddavid <daviddavid> 6.9.3-1.mga8
+ Revision: 1431433
- new version: 6.9.3

* Sat Jul 13 2019 daviddavid <daviddavid> 6.9.2-2.mga8
+ Revision: 1420834
- add upstream patch for CVE-2019-13225 (#1728966)
- NON-upstream patch for CVE-2019-13224 (#1728971)

* Mon May 13 2019 luigiwalser <luigiwalser> 6.9.2-1.mga7
+ Revision: 1397523
- 6.9.2

* Sat Dec 22 2018 daviddavid <daviddavid> 6.9.1-1.mga7
+ Revision: 1344458
- new version: 6.9.1

* Mon Sep 10 2018 daviddavid <daviddavid> 6.9.0-1.mga7
+ Revision: 1258115
- new version: 6.9.0

* Sat Apr 21 2018 daviddavid <daviddavid> 6.8.2-1.mga7
+ Revision: 1220696
- new version: 6.8.2
- kill the onig pkg

* Wed Mar 21 2018 daviddavid <daviddavid> 6.8.1-1.mga7
+ Revision: 1210877
- new version: 6.8.1
- now libmajor is 5

* Sat Mar 17 2018 daviddavid <daviddavid> 6.8.0-1.mga7
+ Revision: 1209997
- new version: 6.8.0

* Sun Jan 28 2018 daviddavid <daviddavid> 6.7.1-1.mga7
+ Revision: 1197522
- new version: 6.7.1

* Sat Jan 13 2018 daviddavid <daviddavid> 6.7.0-1.mga7
+ Revision: 1192518
- initial package oniguruma

